/*********************************************************************************
 *   Kenya - an introductory programming language and development environment    *
 *   Copyright (C) 2001 Robert Chatley                                           *
 *                                                                               *
 *   This program is free software; you can redistribute it and/or               *
 *   modify it under the terms of the GNU General Public License                 *
 *   as published by the Free Software Foundation; either version 2              *
 *   of the License, or (at your option) any later version.                      *
 *                                                                               *
 *   This program is distributed in the hope that it will be useful,             *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of              *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the               *
 *   GNU General Public License for more details.                                *
 *                                                                               *
 *   You should have received a copy of the GNU General Public License           *
 *   along with this program; if not, write to the Free Software                 *
 *   Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA. *
 *                                                                               *
 *   The author can be contacted by email at robert@chatley.com                  *
 *                                                                               *
 *********************************************************************************/

import javax.swing.*;
import javax.swing.event.*;
import javax.swing.text.*;
import java.awt.*;
import java.awt.event.*;
import java.util.Properties;

class KenyaUI extends JFrame {

    JSplitPane pane;
    JTabbedPane tabbedPane;
    JTextArea kenyaArea;
    JTextArea javaArea;
    JTextArea msgsArea;

    JScrollPane kenyaScrollPane;
    JScrollPane javaScrollPane;
    JScrollPane msgsScrollPane;

    DefaultHighlighter highlight;
    DefaultHighlighter.DefaultHighlightPainter painter;
    JToolBar toolbar;
    OutputWindow out;
    Properties prop;

    String lastParsedKCode , lastCompiledKCode , packagename;
    int fontheight;

    KenyaUI( Properties p ) {

	super("Kenya");

	prop = p;
	out = new OutputWindow(this);
        out.outputArea.setEditable(false);

	packagename = "";
	lastParsedKCode = "";
	lastCompiledKCode = "";

	tabbedPane = new JTabbedPane();
	kenyaArea = new JTextArea();
        javaArea = new JTextArea();

	DocumentListener listen = new DocumentListener() {
   	 	public void insertUpdate(DocumentEvent e) {
        	SaveListener.dirty=true;
    	}
    	public void removeUpdate(DocumentEvent e) {
       		SaveListener.dirty=true;
    	}
    	public void changedUpdate(DocumentEvent e) {
        	SaveListener.dirty=true;
    	}
	};
	
	kenyaArea.getDocument().addDocumentListener(listen);
	javaArea.getDocument().addDocumentListener(listen);

	kenyaArea.setTabSize(2);
        javaArea.setTabSize(2);

	msgsArea = new JTextArea();
	msgsArea.setEditable(false);

	setLocation( 150,200 );
	
	this.getContentPane().setLayout( new BorderLayout() );

	Font courier = new Font( "Courier", Font.PLAIN, Integer.parseInt ( prop.getProperty( "font.size" , "14") ) );

	fontheight = kenyaArea.getFontMetrics( courier ).getHeight();

	kenyaArea.setMargin( new Insets( 5, 5, 5, 5 ) );
	kenyaArea.setFont( courier );
        kenyaArea.setLineWrap(true);
        kenyaArea.setWrapStyleWord(true);

	highlight = new DefaultHighlighter();
	painter = new DefaultHighlighter.DefaultHighlightPainter( Color.orange );

	kenyaArea.setHighlighter( highlight );

	javaArea.setMargin( new Insets( 5, 5, 5, 5 ) );
        javaArea.setFont( courier );
        javaArea.setLineWrap(true);
        javaArea.setWrapStyleWord(true);

        kenyaScrollPane = new JScrollPane(kenyaArea);
        javaScrollPane = new JScrollPane(javaArea);
	msgsScrollPane = new JScrollPane(msgsArea);

	int uiHeight =  Integer.parseInt( prop.getProperty( "ui.height" , "600" ) );
	int uiWidth =  Integer.parseInt( prop.getProperty( "ui.width" , "500" ) );

	kenyaScrollPane.setPreferredSize( new Dimension( uiWidth , uiHeight - 100 ) );
        kenyaScrollPane.setVerticalScrollBarPolicy(
                        JScrollPane.VERTICAL_SCROLLBAR_ALWAYS);
        kenyaScrollPane.setBorder(
            BorderFactory.createCompoundBorder(
                BorderFactory.createCompoundBorder(
                                BorderFactory.createTitledBorder("Kenya Code"),
                                BorderFactory.createEmptyBorder(5,5,5,5)),
                kenyaScrollPane.getBorder()));

	javaScrollPane.setPreferredSize( new Dimension( uiWidth , uiHeight - 100 ) );
	javaScrollPane.setVerticalScrollBarPolicy(
                        JScrollPane.VERTICAL_SCROLLBAR_ALWAYS);
        javaScrollPane.setBorder(
            BorderFactory.createCompoundBorder(
                BorderFactory.createCompoundBorder(
                                BorderFactory.createTitledBorder("Java Code"),
                                BorderFactory.createEmptyBorder(5,5,5,5)),
                javaScrollPane.getBorder()));



	toolbar = new KenyaToolBar(this);
	tabbedPane.addTab(" Kenya ", null , kenyaScrollPane, "Write your Kenya code here");
	tabbedPane.addTab(" Java  ", null, javaScrollPane, "See Java code here");
 
	msgsArea.setBorder( BorderFactory.createEtchedBorder( javax.swing.border.EtchedBorder.LOWERED ) );

	msgsScrollPane.setPreferredSize( new Dimension( uiWidth , 100 ) );
	msgsScrollPane.setVerticalScrollBarPolicy(
                        JScrollPane.VERTICAL_SCROLLBAR_AS_NEEDED);
	msgsScrollPane.setBorder( 
            BorderFactory.createCompoundBorder(
                BorderFactory.createCompoundBorder(
                                BorderFactory.createTitledBorder("Messages"),
                                BorderFactory.createEmptyBorder(3,3,3,3)),
                msgsArea.getBorder()));

	pane = new JSplitPane( JSplitPane.VERTICAL_SPLIT ,tabbedPane, msgsScrollPane );

	this.getContentPane().add(pane, BorderLayout.CENTER);
	this.getContentPane().add(toolbar, BorderLayout.NORTH);
    }
}
