/*********************************************************************************
 *   Kenya - an introductory programming language and development environment    *
 *   Copyright (C) 2001 Robert Chatley                                           *
 *                                                                               *
 *   This program is free software; you can redistribute it and/or               *
 *   modify it under the terms of the GNU General Public License                 *
 *   as published by the Free Software Foundation; either version 2              *
 *   of the License, or (at your option) any later version.                      *
 *                                                                               *
 *   This program is distributed in the hope that it will be useful,             *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of              *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the               *
 *   GNU General Public License for more details.                                *
 *                                                                               *
 *   You should have received a copy of the GNU General Public License           *
 *   along with this program; if not, write to the Free Software                 *
 *   Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA. *
 *                                                                               *
 *   The author can be contacted by email at robert@chatley.com                  *
 *                                                                               *
 *********************************************************************************/

import java.io.*;
import java.awt.*;
import java.util.*;
import java.awt.event.*;
import javax.swing.*;
import javax.swing.filechooser.*;

class SaveListener implements ActionListener {
    private KenyaUI ui;

    // cla97 9/10/2001 >>
    boolean saveAs;
    static File file;
    static boolean dirty;
    // cla97 9/10/2001 <<

    SaveListener(KenyaUI f,boolean saveAs)
    {
        ui = f;
        this.saveAs = saveAs;
    }

    public void actionPerformed( ActionEvent event )
    {   
        save(ui,saveAs);
    }

    static void save(KenyaUI ui,boolean saveAs) {
        if (saveAs || file == null) {
            saveWithUI( ui );
        } else {
            saveFile(ui);   
        }   
    }

    static String getSavePath() {
        return file.getParent();
    }

    static void saveWithUI( KenyaUI ui ) {

        try {

            File basedir = new File( ui.prop.getProperty("kenya.base.dir") );
            JFileChooser fc = new JFileChooser(basedir);

            fc.setApproveButtonText("Save");

            ExampleFileFilter filter = new ExampleFileFilter();

            //boolean dotk = ui.tabbedPane.getSelectedIndex() == 0;

            filter.addExtension("k");
            filter.setDescription("Kenya files");

            fc.setFileFilter(filter);

            int returnVal = fc.showSaveDialog(ui);

            if (returnVal == JFileChooser.APPROVE_OPTION) {

                File file = fc.getSelectedFile();

                if ( ! Util.isValidIdentifier( file.getName() ) ) {
                    JOptionPane.showMessageDialog( ui , "Invalid file name. (Names must start with a letter and contain only letters,digits and dots)" );
                    return;
                }

                if ( ! ( file.getName().trim().endsWith(".k") ) ) {
                    file = new File( file.getPath() + ".k" );
                }

                SaveListener.file = file;

                saveFile(ui); // Do the actual saving

                ui.setTitle( "Kenya - " + file.getName() );

            }
        } catch ( Exception e ) {
            ui.msgsArea.setText("An error occurred while saving.");
        }
    }

    public static void saveFile(KenyaUI ui) {
        try {
            String fileName = file.getPath().trim();
            fileName = fileName.substring(0,fileName.length()-2);
            File javaFile = new File(fileName + ".java");


            if ( file.exists() ) {
                file.renameTo( new File( file.getPath() + "~" ) );
            }

            // Save the kenya
            file.createNewFile();
            FileWriter outfile = new FileWriter( file );
            outfile.write( ui.kenyaArea.getText() );
            outfile.close();

            String javaCode = ui.javaArea.getText();
            if (javaCode.length() != 0) {
                if ( javaFile.exists() ) {
                    javaFile.renameTo( new File( javaFile.getPath() + "~" ) );
                }
                javaFile.createNewFile();
                FileWriter javaOutfile = new FileWriter(javaFile);
                javaOutfile.write( javaCode );
                javaOutfile.close();    
            }

            // Set the package
            String name = file.getName().trim();
            ui.packagename = name.substring(0,name.length()-2);
            ui.msgsArea.setText( "Wrote file " + file.getPath() + " and " + javaFile.getPath());
            dirty = false;

        } catch ( Exception e ) {
            ui.msgsArea.setText("An error occurred while saving.");
        }
    } 
    public static void reset() {
        file = null;
        dirty = false;  
    }
}
